@@ -503,13 +503,18 @@ fake_packet( armor_filter_context_t *afx, IOBUF a,
 		afx->buffer_pos = 2; /* skip */
 	    }
 	    else if( n >= 15 &&  p[1] == '-' && p[2] == '-' && p[3] == '-' ) {
-		if( is_armor_header( p, n ) != BEGIN_SIGNATURE ) {
-		    log_info(_("unexpected armor:"));
-		    print_string( stderr, p, n, 0 );
-		    putc('\n', stderr);
+		int type = is_armor_header( p, n );
+		if( afx->not_dash_escaped && type != BEGIN_SIGNATURE )
+		    ; /* this is okay */
+		else {
+		    if( type != BEGIN_SIGNATURE ) {
+			log_info(_("unexpected armor:"));
+			print_string( stderr, p, n, 0 );
+			putc('\n', stderr);
+		    }
+		    lastline = 1;
+		    rc = -1;
 		}
-		lastline = 1;
-		rc = -1;
 	    }
 	}
     }
@@ -989,8 +994,10 @@ armor_filter( void *opaque, int control,
 	    iobuf_writestr(a, tail_strings[afx->what] );
 	    iobuf_writestr(a, "-----\n");
 	}
-	else if( !afx->any_data && !afx->inp_bypass )
+	else if( !afx->any_data && !afx->inp_bypass ) {
 	    log_error(_("no valid OpenPGP data found.\n"));
+	    write_status_text( STATUS_NODATA, "1" );
+	}
 	if( afx->truncated )
 	    log_info(_("invalid armor: line longer than %d characters\n"),
 		      MAX_LINELEN );
