@@ -133,6 +133,16 @@ passphrase_to_dek( u32 *keyid, int cipher_algo, STRING2KEY *s2k, int mode )
 					    :DEFAULT_DIGEST_ALGO;
     }
 
+    if( keyid && !next_pw && is_status_enabled() ) {
+	char buf[50];
+	sprintf( buf, "%08lX%08lX", (ulong)keyid[0], (ulong)keyid[1] );
+	if( keyid[2] && keyid[3] && keyid[0] != keyid[2]
+				 && keyid[1] != keyid[3] )
+	    sprintf( buf+strlen(buf), " %08lX%08lX",
+				      (ulong)keyid[2], (ulong)keyid[3] );
+	write_status_text( STATUS_NEED_PASSPHRASE, buf );
+    }
+
     if( keyid && !opt.batch && !next_pw ) {
 	PKT_public_key *pk = m_alloc_clear( sizeof *pk );
 	size_t n;
@@ -159,15 +169,6 @@ passphrase_to_dek( u32 *keyid, int cipher_algo, STRING2KEY *s2k, int mode )
 	tty_printf("\n");
 	free_public_key( pk );
     }
-    else if( keyid && !next_pw ) {
-	char buf[50];
-	sprintf( buf, "%08lX%08lX", (ulong)keyid[0], (ulong)keyid[1] );
-	if( keyid[2] && keyid[3] && keyid[0] != keyid[2]
-				 && keyid[1] != keyid[3] )
-	    sprintf( buf+strlen(buf), " %08lX%08lX",
-				      (ulong)keyid[2], (ulong)keyid[3] );
-	write_status_text( STATUS_NEED_PASSPHRASE, buf );
-    }
 
     if( next_pw ) {
 	pw = next_pw;
