@@ -455,106 +455,6 @@ sign_file( STRLIST filenames, int detached, STRLIST locusr,
 }
 
 
-#if 0
-/****************
- * Note: We do not calculate the hash over the last CR,LF
- */
-static int
-write_dash_escaped( IOBUF inp, IOBUF out, MD_HANDLE md )
-{
-    int c;
-    int lastlf = 1;
-    int state = 0;
-
-    if( opt.not_dash_escaped ) {
-	lastlf = 0;
-	while( (c = iobuf_get(inp)) != -1 ) {
-	    md_putc(md, c );
-	    iobuf_put( out, c );
-	    lastlf = c;
-	}
-	if( lastlf != '\n' ) {
-	    /* add a missing trailing LF */
-	    md_putc(md, '\n' );
-	    iobuf_put( out, '\n' );
-	}
-
-	return 0;
-    }
-
-    while( (c = iobuf_get(inp)) != -1 ) {
-	if( lastlf ) {
-	    if( c == '-' ) {
-		iobuf_put( out, c );
-		iobuf_put( out, ' ' );
-	    }
-	    else if( c == 'F' && opt.escape_from ) {
-		int i;
-
-		if( state >= 1 )
-		    md_putc(md, '\r');
-		if( state >= 2 )
-		    md_putc(md, '\n');
-		state = 0;
-
-		for( i=1; i < 5 && (c = iobuf_get(inp)) != -1; i++ ) {
-		    if( "From "[i] != c )
-			break;
-		}
-		if( i < 5 ) {
-		    iobuf_write( out, "From", i );
-		    md_write( md, "From", i );
-		    if( c == -1 )
-			break;
-		}
-		else {
-		    iobuf_writestr( out, "- From" );
-		    md_write( md, "From", 4 );
-		}
-	    }
-	}
-
-      again:
-	switch( state ) {
-	  case 0:
-	    if( c == '\r' )
-		state = 1;
-	    else
-		md_putc(md, c );
-	    break;
-	  case 1:
-	    if( c == '\n' )
-		state = 2;
-	    else {
-		md_putc(md, '\r');
-		state = 0;
-		goto again;
-	    }
-	    break;
-	  case 2:
-	    md_putc(md, '\r');
-	    md_putc(md, '\n');
-	    state = 0;
-	    goto again;
-	  default: BUG();
-	}
-	iobuf_put( out, c );
-	lastlf = c == '\n';
-    }
-    if( state == 1 )
-	md_putc(md, '\r');
-    else if( state == 2 ) {  /* file ended with a new line */
-	md_putc(md, '\r');
-	md_putc(md, '\n');
-	iobuf_put( out, '\n');
-    }
-
-    if( !lastlf )
-	iobuf_put( out, '\n' );
-
-    return 0; /* fixme: add error handling */
-}
-#endif
 
 /****************
  * make a clear signature. note that opt.armor is not needed
@@ -563,7 +463,6 @@ int
 clearsign_file( const char *fname, STRLIST locusr, const char *outfile )
 {
     armor_filter_context_t afx;
-    text_filter_context_t tfx;
     MD_HANDLE textmd = NULL;
     IOBUF inp = NULL, out = NULL;
     PACKET pkt;
@@ -572,10 +471,8 @@ clearsign_file( const char *fname, STRLIST locusr, const char *outfile )
     SK_LIST sk_rover = NULL;
     int old_style = opt.rfc1991;
     int only_md5 = 0;
-    int c;
 
     memset( &afx, 0, sizeof afx);
-    memset( &tfx, 0, sizeof tfx);
     init_packet( &pkt );
 
     if( (rc=build_sk_list( locusr, &sk_list, 1, PUBKEY_USAGE_SIG )) )
@@ -647,19 +544,8 @@ clearsign_file( const char *fname, STRLIST locusr, const char *outfile )
 	md_enable(textmd, hash_for(sk->pubkey_algo));
     }
     /*md_start_debug( textmd, "sign" );*/
-    tfx.clearsign = 1;
-    tfx.not_dash_escaped = opt.not_dash_escaped;
-    tfx.escape_from = opt.escape_from;
-    tfx.md = textmd;
-    iobuf_push_filter( inp, text_filter, &tfx );
-    /* read input and write it to the output.  The textfilter handles
-     * the calculation of the hash and the dash escaping */
-    while( (c=iobuf_get(inp)) != -1 )  {
-	if( iobuf_put(out, c) == -1 ) {
-	    rc = G10ERR_WRITE_FILE;
-	    goto leave;
-	}
-    }
+    copy_clearsig_text( out, inp, textmd,
+			!opt.not_dash_escaped, opt.escape_from );
     /* fixme: check for read errors */
 
     /* now write the armor */
